@@ -29,28 +29,36 @@ In the hierarchy of API concepts
 """
 import os
 import warnings
-import grpc
+import grpc  # type: ignore
 
-from google.api_core.gapic_v1 import client_info
+from google.api_core.gapic_v1 import client_info as client_info_lib
+import google.auth  # type: ignore
+from google.auth.credentials import AnonymousCredentials  # type: ignore
 
 from google.cloud import bigtable_v2
 from google.cloud import bigtable_admin_v2
+from google.cloud.bigtable_v2.services.bigtable.transports import BigtableGrpcTransport
+from google.cloud.bigtable_admin_v2.services.bigtable_instance_admin.transports import (
+    BigtableInstanceAdminGrpcTransport,
+)
+from google.cloud.bigtable_admin_v2.services.bigtable_table_admin.transports import (
+    BigtableTableAdminGrpcTransport,
+)
 
-from google.cloud.bigtable import __version__
+from google.cloud import bigtable
 from google.cloud.bigtable.instance import Instance
 from google.cloud.bigtable.cluster import Cluster
 
-from google.cloud.client import ClientWithProject
+from google.cloud.client import ClientWithProject  # type: ignore
 
-from google.cloud.bigtable_admin_v2 import enums
+from google.cloud.bigtable_admin_v2.types import instance
 from google.cloud.bigtable.cluster import _CLUSTER_NAME_RE
-from google.cloud.environment_vars import BIGTABLE_EMULATOR
+from google.cloud.environment_vars import BIGTABLE_EMULATOR  # type: ignore
 
 
-INSTANCE_TYPE_PRODUCTION = enums.Instance.Type.PRODUCTION
-INSTANCE_TYPE_DEVELOPMENT = enums.Instance.Type.DEVELOPMENT
-INSTANCE_TYPE_UNSPECIFIED = enums.Instance.Type.TYPE_UNSPECIFIED
-_CLIENT_INFO = client_info.ClientInfo(client_library_version=__version__)
+INSTANCE_TYPE_PRODUCTION = instance.Instance.Type.PRODUCTION
+INSTANCE_TYPE_DEVELOPMENT = instance.Instance.Type.DEVELOPMENT
+INSTANCE_TYPE_UNSPECIFIED = instance.Instance.Type.TYPE_UNSPECIFIED
 SPANNER_ADMIN_SCOPE = "https://www.googleapis.com/auth/spanner.admin"
 ADMIN_SCOPE = "https://www.googleapis.com/auth/bigtable.admin"
 """Scope for interacting with the Cluster Admin and Table Admin APIs."""
@@ -59,19 +67,23 @@ DATA_SCOPE = "https://www.googleapis.com/auth/bigtable.data"
 READ_ONLY_SCOPE = "https://www.googleapis.com/auth/bigtable.data.readonly"
 """Scope for reading table data."""
 
+_DEFAULT_BIGTABLE_EMULATOR_CLIENT = "google-cloud-bigtable-emulator"
+_GRPC_CHANNEL_OPTIONS = (
+    ("grpc.max_send_message_length", -1),
+    ("grpc.max_receive_message_length", -1),
+    ("grpc.keepalive_time_ms", 30000),
+    ("grpc.keepalive_timeout_ms", 10000),
+)
 
-def _create_gapic_client(client_class, client_options=None):
+
+def _create_gapic_client(client_class, client_options=None, transport=None):
     def inner(self):
-        if self._emulator_host is None:
-            return client_class(
-                credentials=self._credentials,
-                client_info=self._client_info,
-                client_options=client_options,
-            )
-        else:
-            return client_class(
-                channel=self._emulator_channel, client_info=self._client_info
-            )
+        return client_class(
+            credentials=None,
+            client_info=self._client_info,
+            client_options=client_options,
+            transport=transport,
+        )
 
     return inner
 
@@ -142,11 +154,15 @@ class Client(ClientWithProject):
         credentials=None,
         read_only=False,
         admin=False,
-        client_info=_CLIENT_INFO,
+        client_info=None,
         client_options=None,
         admin_client_options=None,
         channel=None,
     ):
+        if client_info is None:
+            client_info = client_info_lib.ClientInfo(
+                client_library_version=bigtable.__version__,
+            )
         if read_only and admin:
             raise ValueError(
                 "A read-only client cannot also perform" "administrative actions."
@@ -158,10 +174,12 @@ class Client(ClientWithProject):
         self._admin = bool(admin)
         self._client_info = client_info
         self._emulator_host = os.getenv(BIGTABLE_EMULATOR)
-        self._emulator_channel = None
 
         if self._emulator_host is not None:
-            self._emulator_channel = grpc.insecure_channel(self._emulator_host)
+            if credentials is None:
+                credentials = AnonymousCredentials()
+            if project is None:
+                project = _DEFAULT_BIGTABLE_EMULATOR_CLIENT
 
         if channel is not None:
             warnings.warn(
@@ -174,7 +192,11 @@ class Client(ClientWithProject):
         self._admin_client_options = admin_client_options
         self._channel = channel
         self.SCOPE = self._get_scopes()
-        super(Client, self).__init__(project=project, credentials=credentials)
+        super(Client, self).__init__(
+            project=project,
+            credentials=credentials,
+            client_options=client_options,
+        )
 
     def _get_scopes(self):
         """Get the scopes corresponding to admin / read-only state.
@@ -192,6 +214,81 @@ class Client(ClientWithProject):
 
         return scopes
 
+    def _emulator_channel(self, transport, options):
+        """Create a channel using self._credentials
+
+        Works in a similar way to ``grpc.secure_channel`` but using
+        ``grpc.local_channel_credentials`` rather than
+        ``grpc.ssh_channel_credentials`` to allow easy connection to a
+        local emulator.
+
+        Returns:
+            grpc.Channel or grpc.aio.Channel
+        """
+        # TODO: Implement a special credentials type for emulator and use
+        # "transport.create_channel" to create gRPC channels once google-auth
+        # extends it's allowed credentials types.
+        # Note: this code also exists in the firestore client.
+        if "GrpcAsyncIOTransport" in str(transport.__name__):
+            return grpc.aio.secure_channel(
+                self._emulator_host,
+                self._local_composite_credentials(),
+                options=options,
+            )
+        else:
+            return grpc.secure_channel(
+                self._emulator_host,
+                self._local_composite_credentials(),
+                options=options,
+            )
+
+    def _local_composite_credentials(self):
+        """Create credentials for the local emulator channel.
+
+        :return: grpc.ChannelCredentials
+        """
+        credentials = google.auth.credentials.with_scopes_if_required(
+            self._credentials, None
+        )
+        request = google.auth.transport.requests.Request()
+
+        # Create the metadata plugin for inserting the authorization header.
+        metadata_plugin = google.auth.transport.grpc.AuthMetadataPlugin(
+            credentials, request
+        )
+
+        # Create a set of grpc.CallCredentials using the metadata plugin.
+        google_auth_credentials = grpc.metadata_call_credentials(metadata_plugin)
+
+        # Using the local_credentials to allow connection to emulator
+        local_credentials = grpc.local_channel_credentials()
+
+        # Combine the local credentials and the authorization credentials.
+        return grpc.composite_channel_credentials(
+            local_credentials, google_auth_credentials
+        )
+
+    def _create_gapic_client_channel(self, client_class, grpc_transport):
+        if self._emulator_host is not None:
+            api_endpoint = self._emulator_host
+        elif self._client_options and self._client_options.api_endpoint:
+            api_endpoint = self._client_options.api_endpoint
+        else:
+            api_endpoint = client_class.DEFAULT_ENDPOINT
+
+        if self._emulator_host is not None:
+            channel = self._emulator_channel(
+                transport=grpc_transport,
+                options=_GRPC_CHANNEL_OPTIONS,
+            )
+        else:
+            channel = grpc_transport.create_channel(
+                host=api_endpoint,
+                credentials=self._credentials,
+                options=_GRPC_CHANNEL_OPTIONS,
+            )
+        return grpc_transport(channel=channel, host=api_endpoint)
+
     @property
     def project_path(self):
         """Project name to be used with Instance Admin API.
@@ -204,8 +301,9 @@ class Client(ClientWithProject):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_project_path]
-            :end-before: [END bigtable_project_path]
+            :start-after: [START bigtable_api_project_path]
+            :end-before: [END bigtable_api_project_path]
+            :dedent: 4
 
         The project name is of the form
 
@@ -214,7 +312,7 @@ class Client(ClientWithProject):
         :rtype: str
         :returns: Return a fully-qualified project string.
         """
-        return self.instance_admin_client.project_path(self.project)
+        return self.instance_admin_client.common_project_path(self.project)
 
     @property
     def table_data_client(self):
@@ -223,15 +321,22 @@ class Client(ClientWithProject):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_table_data_client]
-            :end-before: [END bigtable_table_data_client]
+            :start-after: [START bigtable_api_table_data_client]
+            :end-before: [END bigtable_api_table_data_client]
+            :dedent: 4
 
         :rtype: :class:`.bigtable_v2.BigtableClient`
         :returns: A BigtableClient object.
         """
         if self._table_data_client is None:
+            transport = self._create_gapic_client_channel(
+                bigtable_v2.BigtableClient,
+                BigtableGrpcTransport,
+            )
             klass = _create_gapic_client(
-                bigtable_v2.BigtableClient, client_options=self._client_options
+                bigtable_v2.BigtableClient,
+                client_options=self._client_options,
+                transport=transport,
             )
             self._table_data_client = klass(self)
         return self._table_data_client
@@ -243,8 +348,9 @@ class Client(ClientWithProject):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_table_admin_client]
-            :end-before: [END bigtable_table_admin_client]
+            :start-after: [START bigtable_api_table_admin_client]
+            :end-before: [END bigtable_api_table_admin_client]
+            :dedent: 4
 
         :rtype: :class:`.bigtable_admin_pb2.BigtableTableAdmin`
         :returns: A BigtableTableAdmin instance.
@@ -255,9 +361,15 @@ class Client(ClientWithProject):
         if self._table_admin_client is None:
             if not self._admin:
                 raise ValueError("Client is not an admin client.")
+
+            transport = self._create_gapic_client_channel(
+                bigtable_admin_v2.BigtableTableAdminClient,
+                BigtableTableAdminGrpcTransport,
+            )
             klass = _create_gapic_client(
                 bigtable_admin_v2.BigtableTableAdminClient,
                 client_options=self._admin_client_options,
+                transport=transport,
             )
             self._table_admin_client = klass(self)
         return self._table_admin_client
@@ -269,8 +381,9 @@ class Client(ClientWithProject):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_instance_admin_client]
-            :end-before: [END bigtable_instance_admin_client]
+            :start-after: [START bigtable_api_instance_admin_client]
+            :end-before: [END bigtable_api_instance_admin_client]
+            :dedent: 4
 
         :rtype: :class:`.bigtable_admin_pb2.BigtableInstanceAdmin`
         :returns: A BigtableInstanceAdmin instance.
@@ -281,9 +394,15 @@ class Client(ClientWithProject):
         if self._instance_admin_client is None:
             if not self._admin:
                 raise ValueError("Client is not an admin client.")
+
+            transport = self._create_gapic_client_channel(
+                bigtable_admin_v2.BigtableInstanceAdminClient,
+                BigtableInstanceAdminGrpcTransport,
+            )
             klass = _create_gapic_client(
                 bigtable_admin_v2.BigtableInstanceAdminClient,
                 client_options=self._admin_client_options,
+                transport=transport,
             )
             self._instance_admin_client = klass(self)
         return self._instance_admin_client
@@ -294,8 +413,9 @@ class Client(ClientWithProject):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_create_prod_instance]
-            :end-before: [END bigtable_create_prod_instance]
+            :start-after: [START bigtable_api_create_prod_instance]
+            :end-before: [END bigtable_api_create_prod_instance]
+            :dedent: 4
 
         :type instance_id: str
         :param instance_id: The ID of the instance.
@@ -310,10 +430,10 @@ class Client(ClientWithProject):
         :param instance_type: (Optional) The type of the instance.
                                Possible values are represented
                                by the following constants:
-                               :data:`google.cloud.bigtable.enums.InstanceType.PRODUCTION`.
-                               :data:`google.cloud.bigtable.enums.InstanceType.DEVELOPMENT`,
+                               :data:`google.cloud.bigtable.instance.InstanceType.PRODUCTION`.
+                               :data:`google.cloud.bigtable.instance.InstanceType.DEVELOPMENT`,
                                Defaults to
-                               :data:`google.cloud.bigtable.enums.InstanceType.UNSPECIFIED`.
+                               :data:`google.cloud.bigtable.instance.InstanceType.UNSPECIFIED`.
 
         :type labels: dict
         :param labels: (Optional) Labels are a flexible and lightweight
@@ -343,8 +463,9 @@ class Client(ClientWithProject):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_list_instances]
-            :end-before: [END bigtable_list_instances]
+            :start-after: [START bigtable_api_list_instances]
+            :end-before: [END bigtable_api_list_instances]
+            :dedent: 4
 
         :rtype: tuple
         :returns:
@@ -353,7 +474,9 @@ class Client(ClientWithProject):
             'failed_locations' is a list of locations which could not
             be resolved.
         """
-        resp = self.instance_admin_client.list_instances(self.project_path)
+        resp = self.instance_admin_client.list_instances(
+            request={"parent": self.project_path}
+        )
         instances = [Instance.from_pb(instance, self) for instance in resp.instances]
         return instances, resp.failed_locations
 
@@ -363,8 +486,9 @@ class Client(ClientWithProject):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_list_clusters_in_project]
-            :end-before: [END bigtable_list_clusters_in_project]
+            :start-after: [START bigtable_api_list_clusters_in_project]
+            :end-before: [END bigtable_api_list_clusters_in_project]
+            :dedent: 4
 
         :rtype: tuple
         :returns:
@@ -374,7 +498,9 @@ class Client(ClientWithProject):
             locations which could not be resolved.
         """
         resp = self.instance_admin_client.list_clusters(
-            self.instance_admin_client.instance_path(self.project, "-")
+            request={
+                "parent": self.instance_admin_client.instance_path(self.project, "-")
+            }
         )
         clusters = []
         instances = {}
