@@ -14,16 +14,17 @@
 
 """User-friendly container for Google Cloud Bigtable Instance."""
 
-
 import re
 
-from google.cloud.bigtable.table import Table
-from google.cloud.bigtable.cluster import Cluster
 from google.cloud.bigtable.app_profile import AppProfile
+from google.cloud.bigtable.cluster import Cluster
+from google.cloud.bigtable.table import Table
 
 from google.protobuf import field_mask_pb2
 
-from google.cloud.bigtable_admin_v2.types import instance_pb2, options_pb2
+from google.cloud.bigtable_admin_v2.types import instance
+
+from google.iam.v1 import options_pb2  # type: ignore
 
 from google.api_core.exceptions import NotFound
 
@@ -122,7 +123,7 @@ class Instance(object):
         if not instance_pb.display_name:  # Simple field (string)
             raise ValueError("Instance protobuf does not contain display_name")
         self.display_name = instance_pb.display_name
-        self.type_ = instance_pb.type
+        self.type_ = instance_pb.type_
         self.labels = dict(instance_pb.labels)
         self._state = instance_pb.state
 
@@ -133,10 +134,11 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_instance_from_pb]
-            :end-before: [END bigtable_instance_from_pb]
+            :start-after: [START bigtable_api_instance_from_pb]
+            :end-before: [END bigtable_api_instance_from_pb]
+            :dedent: 4
 
-        :type instance_pb: :class:`instance_pb2.Instance`
+        :type instance_pb: :class:`instance.Instance`
         :param instance_pb: An instance protobuf object.
 
         :type client: :class:`Client <google.cloud.bigtable.client.Client>`
@@ -177,8 +179,9 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_instance_name]
-            :end-before: [END bigtable_instance_name]
+            :start-after: [START bigtable_api_instance_name]
+            :end-before: [END bigtable_api_instance_name]
+            :dedent: 4
 
         The instance name is of the form
 
@@ -198,8 +201,9 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_instance_state]
-            :end-before: [END bigtable_instance_state]
+            :start-after: [START bigtable_api_instance_state]
+            :end-before: [END bigtable_api_instance_state]
+            :dedent: 4
 
         """
         return self._state
@@ -224,14 +228,18 @@ class Instance(object):
         serve_nodes=None,
         default_storage_type=None,
         clusters=None,
+        min_serve_nodes=None,
+        max_serve_nodes=None,
+        cpu_utilization_percent=None,
     ):
         """Create this instance.
 
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_create_prod_instance]
-            :end-before: [END bigtable_create_prod_instance]
+            :start-after: [START bigtable_api_create_prod_instance]
+            :end-before: [END bigtable_api_create_prod_instance]
+            :dedent: 4
 
         .. note::
 
@@ -265,7 +273,7 @@ class Instance(object):
                                       Possible values are represented
                                       by the following constants:
                                       :data:`google.cloud.bigtable.enums.StorageType.SSD`.
-                                      :data:`google.cloud.bigtable.enums.StorageType.SHD`,
+                                      :data:`google.cloud.bigtable.enums.StorageType.HDD`,
                                       Defaults to
                                       :data:`google.cloud.bigtable.enums.StorageType.UNSPECIFIED`.
 
@@ -298,12 +306,18 @@ class Instance(object):
                     location_id=location_id,
                     serve_nodes=serve_nodes,
                     default_storage_type=default_storage_type,
+                    min_serve_nodes=None,
+                    max_serve_nodes=None,
+                    cpu_utilization_percent=None,
                 )
             ]
         elif (
             location_id is not None
             or serve_nodes is not None
             or default_storage_type is not None
+            or min_serve_nodes is not None
+            or max_serve_nodes is not None
+            or cpu_utilization_percent is not None
         ):
             raise ValueError(
                 "clusters and one of location_id, serve_nodes, \
@@ -311,17 +325,19 @@ class Instance(object):
                              simultaneously."
             )
 
-        instance_pb = instance_pb2.Instance(
-            display_name=self.display_name, type=self.type_, labels=self.labels
+        instance_pb = instance.Instance(
+            display_name=self.display_name, type_=self.type_, labels=self.labels
         )
 
         parent = self._client.project_path
 
         return self._client.instance_admin_client.create_instance(
-            parent=parent,
-            instance_id=self.instance_id,
-            instance=instance_pb,
-            clusters={c.cluster_id: c._to_pb() for c in clusters},
+            request={
+                "parent": parent,
+                "instance_id": self.instance_id,
+                "instance": instance_pb,
+                "clusters": {c.cluster_id: c._to_pb() for c in clusters},
+            }
         )
 
     def exists(self):
@@ -330,14 +346,15 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_check_instance_exists]
-            :end-before: [END bigtable_check_instance_exists]
+            :start-after: [START bigtable_api_check_instance_exists]
+            :end-before: [END bigtable_api_check_instance_exists]
+            :dedent: 4
 
         :rtype: bool
         :returns: True if the table exists, else False.
         """
         try:
-            self._client.instance_admin_client.get_instance(name=self.name)
+            self._client.instance_admin_client.get_instance(request={"name": self.name})
             return True
         # NOTE: There could be other exceptions that are returned to the user.
         except NotFound:
@@ -349,10 +366,13 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_reload_instance]
-            :end-before: [END bigtable_reload_instance]
+            :start-after: [START bigtable_api_reload_instance]
+            :end-before: [END bigtable_api_reload_instance]
+            :dedent: 4
         """
-        instance_pb = self._client.instance_admin_client.get_instance(self.name)
+        instance_pb = self._client.instance_admin_client.get_instance(
+            request={"name": self.name}
+        )
 
         # NOTE: _update_from_pb does not check that the project and
         #       instance ID on the response match the request.
@@ -364,8 +384,9 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_update_instance]
-            :end-before: [END bigtable_update_instance]
+            :start-after: [START bigtable_api_update_instance]
+            :end-before: [END bigtable_api_update_instance]
+            :dedent: 4
 
         .. note::
 
@@ -393,15 +414,15 @@ class Instance(object):
             update_mask_pb.paths.append("type")
         if self.labels is not None:
             update_mask_pb.paths.append("labels")
-        instance_pb = instance_pb2.Instance(
+        instance_pb = instance.Instance(
             name=self.name,
             display_name=self.display_name,
-            type=self.type_,
+            type_=self.type_,
             labels=self.labels,
         )
 
         return self._client.instance_admin_client.partial_update_instance(
-            instance=instance_pb, update_mask=update_mask_pb
+            request={"instance": instance_pb, "update_mask": update_mask_pb}
         )
 
     def delete(self):
@@ -410,8 +431,9 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_delete_instance]
-            :end-before: [END bigtable_delete_instance]
+            :start-after: [START bigtable_api_delete_instance]
+            :end-before: [END bigtable_api_delete_instance]
+            :dedent: 4
 
         Marks an instance and all of its tables for permanent deletion
         in 7 days.
@@ -432,7 +454,7 @@ class Instance(object):
           irrevocably disappear from the API, and their data will be
           permanently deleted.
         """
-        self._client.instance_admin_client.delete_instance(name=self.name)
+        self._client.instance_admin_client.delete_instance(request={"name": self.name})
 
     def get_iam_policy(self, requested_policy_version=None):
         """Gets the access control policy for an instance resource.
@@ -440,8 +462,9 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_get_iam_policy]
-            :end-before: [END bigtable_get_iam_policy]
+            :start-after: [START bigtable_api_get_iam_policy]
+            :end-before: [END bigtable_api_get_iam_policy]
+            :dedent: 4
 
         :type requested_policy_version: int or ``NoneType``
         :param requested_policy_version: Optional. The version of IAM policies to request.
@@ -466,7 +489,7 @@ class Instance(object):
 
         instance_admin_client = self._client.instance_admin_client
 
-        resp = instance_admin_client.get_iam_policy(**args)
+        resp = instance_admin_client.get_iam_policy(request=args)
         return Policy.from_pb(resp)
 
     def set_iam_policy(self, policy):
@@ -479,8 +502,9 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_set_iam_policy]
-            :end-before: [END bigtable_set_iam_policy]
+            :start-after: [START bigtable_api_set_iam_policy]
+            :end-before: [END bigtable_api_set_iam_policy]
+            :dedent: 4
 
         :type policy: :class:`google.cloud.bigtable.policy.Policy`
         :param policy: A new IAM policy to replace the current IAM policy
@@ -491,7 +515,7 @@ class Instance(object):
         """
         instance_admin_client = self._client.instance_admin_client
         resp = instance_admin_client.set_iam_policy(
-            resource=self.name, policy=policy.to_pb()
+            request={"resource": self.name, "policy": policy.to_pb()}
         )
         return Policy.from_pb(resp)
 
@@ -502,8 +526,9 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_test_iam_permissions]
-            :end-before: [END bigtable_test_iam_permissions]
+            :start-after: [START bigtable_api_test_iam_permissions]
+            :end-before: [END bigtable_api_test_iam_permissions]
+            :dedent: 4
 
         :type permissions: list
         :param permissions: The set of permissions to check for
@@ -519,20 +544,29 @@ class Instance(object):
         """
         instance_admin_client = self._client.instance_admin_client
         resp = instance_admin_client.test_iam_permissions(
-            resource=self.name, permissions=permissions
+            request={"resource": self.name, "permissions": permissions}
         )
         return list(resp.permissions)
 
     def cluster(
-        self, cluster_id, location_id=None, serve_nodes=None, default_storage_type=None
+        self,
+        cluster_id,
+        location_id=None,
+        serve_nodes=None,
+        default_storage_type=None,
+        kms_key_name=None,
+        min_serve_nodes=None,
+        max_serve_nodes=None,
+        cpu_utilization_percent=None,
     ):
         """Factory to create a cluster associated with this instance.
 
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_create_cluster]
-            :end-before: [END bigtable_create_cluster]
+            :start-after: [START bigtable_api_create_cluster]
+            :end-before: [END bigtable_api_create_cluster]
+            :dedent: 4
 
         :type cluster_id: str
         :param cluster_id: The ID of the cluster.
@@ -553,12 +587,28 @@ class Instance(object):
                                      Possible values are represented by the
                                      following constants:
                                      :data:`google.cloud.bigtable.enums.StorageType.SSD`.
-                                     :data:`google.cloud.bigtable.enums.StorageType.SHD`,
+                                     :data:`google.cloud.bigtable.enums.StorageType.HDD`,
                                      Defaults to
                                      :data:`google.cloud.bigtable.enums.StorageType.UNSPECIFIED`.
 
         :rtype: :class:`~google.cloud.bigtable.instance.Cluster`
         :returns: a cluster owned by this instance.
+
+        :type kms_key_name: str
+        :param kms_key_name: (Optional, Creation Only) The name of the KMS customer
+                             managed encryption key (CMEK) to use for at-rest encryption
+                             of data in this cluster.  If omitted, Google's default
+                             encryption will be used. If specified, the requirements for
+                             this key are:
+
+                             1) The Cloud Bigtable service account associated with the
+                                project that contains the cluster must be granted the
+                                ``cloudkms.cryptoKeyEncrypterDecrypter`` role on the
+                                CMEK.
+                             2) Only regional keys can be used and the region of the
+                                CMEK key must match the region of the cluster.
+                             3) All clusters within an instance must use the same CMEK
+                                key.
         """
         return Cluster(
             cluster_id,
@@ -566,6 +616,10 @@ class Instance(object):
             location_id=location_id,
             serve_nodes=serve_nodes,
             default_storage_type=default_storage_type,
+            kms_key_name=kms_key_name,
+            min_serve_nodes=min_serve_nodes,
+            max_serve_nodes=max_serve_nodes,
+            cpu_utilization_percent=cpu_utilization_percent,
         )
 
     def list_clusters(self):
@@ -574,8 +628,9 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_list_clusters_on_instance]
-            :end-before: [END bigtable_list_clusters_on_instance]
+            :start-after: [START bigtable_api_list_clusters_on_instance]
+            :end-before: [END bigtable_api_list_clusters_on_instance]
+            :dedent: 4
 
         :rtype: tuple
         :returns:
@@ -584,7 +639,9 @@ class Instance(object):
             'failed_locations' is a list of locations which could not
             be resolved.
         """
-        resp = self._client.instance_admin_client.list_clusters(self.name)
+        resp = self._client.instance_admin_client.list_clusters(
+            request={"parent": self.name}
+        )
         clusters = [Cluster.from_pb(cluster, self) for cluster in resp.clusters]
         return clusters, resp.failed_locations
 
@@ -594,12 +651,16 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_create_table]
-            :end-before: [END bigtable_create_table]
+            :start-after: [START bigtable_api_create_table]
+            :end-before: [END bigtable_api_create_table]
+            :dedent: 4
 
         :type table_id: str
         :param table_id: The ID of the table.
 
+        :type mutation_timeout: int
+        :param mutation_timeout: (Optional) The overriding mutation timeout.
+
         :type app_profile_id: str
         :param app_profile_id: (Optional) The unique name of the AppProfile.
 
@@ -619,18 +680,21 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_list_tables]
-            :end-before: [END bigtable_list_tables]
+            :start-after: [START bigtable_api_list_tables]
+            :end-before: [END bigtable_api_list_tables]
+            :dedent: 4
 
         :rtype: list of :class:`Table <google.cloud.bigtable.table.Table>`
         :returns: The list of tables owned by the instance.
         :raises: :class:`ValueError <exceptions.ValueError>` if one of the
                  returned tables has a name that is not of the expected format.
         """
-        table_list_pb = self._client.table_admin_client.list_tables(self.name)
+        table_list_pb = self._client.table_admin_client.list_tables(
+            request={"parent": self.name}
+        )
 
         result = []
-        for table_pb in table_list_pb:
+        for table_pb in table_list_pb.tables:
             table_prefix = self.name + "/tables/"
             if not table_pb.name.startswith(table_prefix):
                 raise ValueError(
@@ -647,6 +711,7 @@ class Instance(object):
         routing_policy_type=None,
         description=None,
         cluster_id=None,
+        multi_cluster_ids=None,
         allow_transactional_writes=None,
     ):
         """Factory to create AppProfile associated with this instance.
@@ -654,8 +719,9 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_create_app_profile]
-            :end-before: [END bigtable_create_app_profile]
+            :start-after: [START bigtable_api_create_app_profile]
+            :end-before: [END bigtable_api_create_app_profile]
+            :dedent: 4
 
         :type app_profile_id: str
         :param app_profile_id: The ID of the AppProfile. Must be of the form
@@ -677,6 +743,11 @@ class Instance(object):
                             when routing_policy_type is
                             ROUTING_POLICY_TYPE_SINGLE.
 
+        :type: multi_cluster_ids: list
+        :param: multi_cluster_ids: (Optional) The set of clusters to route to.
+                            The order is ignored; clusters will be tried in order of distance.
+                            If left empty, all clusters are eligible.
+
         :type: allow_transactional_writes: bool
         :param: allow_transactional_writes: (Optional) If true, allow
                                             transactional writes for
@@ -691,6 +762,7 @@ class Instance(object):
             routing_policy_type=routing_policy_type,
             description=description,
             cluster_id=cluster_id,
+            multi_cluster_ids=multi_cluster_ids,
             allow_transactional_writes=allow_transactional_writes,
         )
 
@@ -700,8 +772,9 @@ class Instance(object):
         For example:
 
         .. literalinclude:: snippets.py
-            :start-after: [START bigtable_list_app_profiles]
-            :end-before: [END bigtable_list_app_profiles]
+            :start-after: [START bigtable_api_list_app_profiles]
+            :end-before: [END bigtable_api_list_app_profiles]
+            :dedent: 4
 
         :rtype: :list:[`~google.cloud.bigtable.app_profile.AppProfile`]
         :returns: A :list:[`~google.cloud.bigtable.app_profile.AppProfile`].
@@ -709,5 +782,7 @@ class Instance(object):
                   :class:`~google.cloud.bigtable.app_profile.AppProfile`
                   instances.
         """
-        resp = self._client.instance_admin_client.list_app_profiles(self.name)
+        resp = self._client.instance_admin_client.list_app_profiles(
+            request={"parent": self.name}
+        )
         return [AppProfile.from_pb(app_profile, self) for app_profile in resp]
