@@ -17,12 +17,10 @@
 
 import struct
 
-import six
-
-from google.cloud._helpers import _datetime_from_microseconds
-from google.cloud._helpers import _microseconds_from_datetime
-from google.cloud._helpers import _to_bytes
-from google.cloud.bigtable_v2.proto import data_pb2 as data_v2_pb2
+from google.cloud._helpers import _datetime_from_microseconds  # type: ignore
+from google.cloud._helpers import _microseconds_from_datetime  # type: ignore
+from google.cloud._helpers import _to_bytes  # type: ignore
+from google.cloud.bigtable_v2.types import data as data_v2_pb2
 
 
 _PACK_I64 = struct.Struct(">q").pack
@@ -59,8 +57,9 @@ class Row(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_row_key]
-            :end-before: [END bigtable_row_row_key]
+            :start-after: [START bigtable_api_row_row_key]
+            :end-before: [END bigtable_api_row_row_key]
+            :dedent: 4
 
         :rtype: bytes
         :returns: The key for the current row.
@@ -74,8 +73,9 @@ class Row(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_table]
-            :end-before: [END bigtable_row_table]
+            :start-after: [START bigtable_api_row_table]
+            :end-before: [END bigtable_api_row_table]
+            :dedent: 4
 
         :rtype: table: :class:`Table <google.cloud.bigtable.table.Table>`
         :returns: table: The table that owns the row.
@@ -149,7 +149,7 @@ class _SetDeleteRow(Row):
                       :meth:`_get_mutations`.
         """
         column = _to_bytes(column)
-        if isinstance(value, six.integer_types):
+        if isinstance(value, int):
             value = _PACK_I64(value)
         value = _to_bytes(value)
         if timestamp is None:
@@ -293,19 +293,19 @@ class DirectRow(_SetDeleteRow):
         return self._pb_mutations
 
     def get_mutations_size(self):
-        """ Gets the total mutations size for current row
+        """Gets the total mutations size for current row
 
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_get_mutations_size]
-            :end-before: [END bigtable_row_get_mutations_size]
-
+            :start-after: [START bigtable_api_row_get_mutations_size]
+            :end-before: [END bigtable_api_row_get_mutations_size]
+            :dedent: 4
         """
 
         mutation_size = 0
         for mutation in self._get_mutations():
-            mutation_size += mutation.ByteSize()
+            mutation_size += mutation._pb.ByteSize()
 
         return mutation_size
 
@@ -326,8 +326,9 @@ class DirectRow(_SetDeleteRow):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_set_cell]
-            :end-before: [END bigtable_row_set_cell]
+            :start-after: [START bigtable_api_row_set_cell]
+            :end-before: [END bigtable_api_row_set_cell]
+            :dedent: 4
 
         :type column_family_id: str
         :param column_family_id: The column family that contains the column.
@@ -361,9 +362,9 @@ class DirectRow(_SetDeleteRow):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_delete]
-            :end-before: [END bigtable_row_delete]
-
+            :start-after: [START bigtable_api_row_delete]
+            :end-before: [END bigtable_api_row_delete]
+            :dedent: 4
         """
         self._delete(state=None)
 
@@ -380,8 +381,9 @@ class DirectRow(_SetDeleteRow):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_delete_cell]
-            :end-before: [END bigtable_row_delete_cell]
+            :start-after: [START bigtable_api_row_delete_cell]
+            :end-before: [END bigtable_api_row_delete_cell]
+            :dedent: 4
 
         :type column_family_id: str
         :param column_family_id: The column family that contains the column
@@ -413,8 +415,9 @@ class DirectRow(_SetDeleteRow):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_delete_cells]
-            :end-before: [END bigtable_row_delete_cells]
+            :start-after: [START bigtable_api_row_delete_cells]
+            :end-before: [END bigtable_api_row_delete_cells]
+            :dedent: 4
 
         :type column_family_id: str
         :param column_family_id: The column family that contains the column
@@ -448,24 +451,31 @@ class DirectRow(_SetDeleteRow):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_commit]
-            :end-before: [END bigtable_row_commit]
+            :start-after: [START bigtable_api_row_commit]
+            :end-before: [END bigtable_api_row_commit]
+            :dedent: 4
 
+        :rtype: :class:`~google.rpc.status_pb2.Status`
+        :returns: A response status (`google.rpc.status_pb2.Status`)
+                  representing success or failure of the row committed.
         :raises: :exc:`~.table.TooManyMutationsError` if the number of
                  mutations is greater than 100,000.
         """
-        self._table.mutate_rows([self])
+        response = self._table.mutate_rows([self])
+
         self.clear()
 
+        return response[0]
+
     def clear(self):
         """Removes all currently accumulated mutations on the current row.
 
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_clear]
-            :end-before: [END bigtable_row_clear]
-
+            :start-after: [START bigtable_api_row_clear]
+            :end-before: [END bigtable_api_row_clear]
+            :dedent: 4
         """
         del self._pb_mutations[:]
 
@@ -555,8 +565,9 @@ class ConditionalRow(_SetDeleteRow):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_commit]
-            :end-before: [END bigtable_row_commit]
+            :start-after: [START bigtable_api_row_commit]
+            :end-before: [END bigtable_api_row_commit]
+            :dedent: 4
 
         :rtype: bool
         :returns: Flag indicating if the filter was matched (which also
@@ -608,8 +619,9 @@ class ConditionalRow(_SetDeleteRow):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_set_cell]
-            :end-before: [END bigtable_row_set_cell]
+            :start-after: [START bigtable_api_row_set_cell]
+            :end-before: [END bigtable_api_row_set_cell]
+            :dedent: 4
 
         :type column_family_id: str
         :param column_family_id: The column family that contains the column.
@@ -649,8 +661,9 @@ class ConditionalRow(_SetDeleteRow):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_delete]
-            :end-before: [END bigtable_row_delete]
+            :start-after: [START bigtable_api_row_delete]
+            :end-before: [END bigtable_api_row_delete]
+            :dedent: 4
 
         :type state: bool
         :param state: (Optional) The state that the mutation should be
@@ -671,8 +684,9 @@ class ConditionalRow(_SetDeleteRow):
          For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_delete_cell]
-            :end-before: [END bigtable_row_delete_cell]
+            :start-after: [START bigtable_api_row_delete_cell]
+            :end-before: [END bigtable_api_row_delete_cell]
+            :dedent: 4
 
         :type column_family_id: str
         :param column_family_id: The column family that contains the column
@@ -708,8 +722,9 @@ class ConditionalRow(_SetDeleteRow):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_delete_cells]
-            :end-before: [END bigtable_row_delete_cells]
+            :start-after: [START bigtable_api_row_delete_cells]
+            :end-before: [END bigtable_api_row_delete_cells]
+            :dedent: 4
 
         :type column_family_id: str
         :param column_family_id: The column family that contains the column
@@ -742,9 +757,9 @@ class ConditionalRow(_SetDeleteRow):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_clear]
-            :end-before: [END bigtable_row_clear]
-
+            :start-after: [START bigtable_api_row_clear]
+            :end-before: [END bigtable_api_row_clear]
+            :dedent: 4
         """
         del self._true_pb_mutations[:]
         del self._false_pb_mutations[:]
@@ -781,9 +796,9 @@ class AppendRow(Row):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_clear]
-            :end-before: [END bigtable_row_clear]
-
+            :start-after: [START bigtable_api_row_clear]
+            :end-before: [END bigtable_api_row_clear]
+            :dedent: 4
         """
         del self._rule_pb_list[:]
 
@@ -800,8 +815,9 @@ class AppendRow(Row):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_append_cell_value]
-            :end-before: [END bigtable_row_append_cell_value]
+            :start-after: [START bigtable_api_row_append_cell_value]
+            :end-before: [END bigtable_api_row_append_cell_value]
+            :dedent: 4
 
         :type column_family_id: str
         :param column_family_id: The column family that contains the column.
@@ -840,8 +856,9 @@ class AppendRow(Row):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_increment_cell_value]
-            :end-before: [END bigtable_row_increment_cell_value]
+            :start-after: [START bigtable_api_row_increment_cell_value]
+            :end-before: [END bigtable_api_row_increment_cell_value]
+            :dedent: 4
 
         :type column_family_id: str
         :param column_family_id: The column family that contains the column.
@@ -886,8 +903,9 @@ class AppendRow(Row):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_commit]
-            :end-before: [END bigtable_row_commit]
+            :start-after: [START bigtable_api_row_commit]
+            :end-before: [END bigtable_api_row_commit]
+            :dedent: 4
 
         :rtype: dict
         :returns: The new contents of all modified cells. Returned as a
