@@ -16,16 +16,15 @@
 
 
 import copy
-import six
 
-import grpc
+import grpc  # type: ignore
 
 from google.api_core import exceptions
 from google.api_core import retry
-from google.cloud._helpers import _datetime_from_microseconds
-from google.cloud._helpers import _to_bytes
-from google.cloud.bigtable_v2.proto import bigtable_pb2 as data_messages_v2_pb2
-from google.cloud.bigtable_v2.proto import data_pb2 as data_v2_pb2
+from google.cloud._helpers import _datetime_from_microseconds  # type: ignore
+from google.cloud._helpers import _to_bytes  # type: ignore
+from google.cloud.bigtable_v2.types import bigtable as data_messages_v2_pb2
+from google.cloud.bigtable_v2.types import data as data_v2_pb2
 
 _MISSING_COLUMN_FAMILY = "Column family {} is not among the cells stored in this row."
 _MISSING_COLUMN = (
@@ -169,8 +168,8 @@ class PartialRowData(object):
         :returns: Dictionary containing all the data in the cells of this row.
         """
         result = {}
-        for column_family_id, columns in six.iteritems(self._cells):
-            for column_qual, cells in six.iteritems(columns):
+        for column_family_id, columns in self._cells.items():
+            for column_qual, cells in columns.items():
                 key = _to_bytes(column_family_id) + b":" + _to_bytes(column_qual)
                 result[key] = cells
         return result
@@ -182,8 +181,9 @@ class PartialRowData(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_data_cells]
-            :end-before: [END bigtable_row_data_cells]
+            :start-after: [START bigtable_api_row_data_cells]
+            :end-before: [END bigtable_api_row_data_cells]
+            :dedent: 4
 
         :rtype: dict
         :returns: Dictionary of the :class:`Cell` objects accumulated. This
@@ -208,8 +208,9 @@ class PartialRowData(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_find_cells]
-            :end-before: [END bigtable_row_find_cells]
+            :start-after: [START bigtable_api_row_find_cells]
+            :end-before: [END bigtable_api_row_find_cells]
+            :dedent: 4
 
         Args:
             column_family_id (str): The ID of the column family. Must be of the
@@ -245,8 +246,9 @@ class PartialRowData(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_cell_value]
-            :end-before: [END bigtable_row_cell_value]
+            :start-after: [START bigtable_api_row_cell_value]
+            :end-before: [END bigtable_api_row_cell_value]
+            :dedent: 4
 
         Args:
             column_family_id (str): The ID of the column family. Must be of the
@@ -286,8 +288,9 @@ class PartialRowData(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_row_cell_values]
-            :end-before: [END bigtable_row_cell_values]
+            :start-after: [START bigtable_api_row_cell_values]
+            :end-before: [END bigtable_api_row_cell_values]
+            :dedent: 4
 
         Args:
             column_family_id (str): The ID of the column family. Must be of the
@@ -318,11 +321,15 @@ class PartialRowData(object):
 
 
 class InvalidReadRowsResponse(RuntimeError):
-    """Exception raised to to invalid response data from back-end."""
+    """Exception raised to invalid response data from back-end."""
 
 
 class InvalidChunk(RuntimeError):
-    """Exception raised to to invalid chunk data from back-end."""
+    """Exception raised to invalid chunk data from back-end."""
+
+
+class InvalidRetryRequest(RuntimeError):
+    """Exception raised when retry request is invalid."""
 
 
 def _retry_read_rows_exception(exc):
@@ -400,7 +407,14 @@ class PartialRowsData(object):
         self.read_method = read_method
         self.request = request
         self.retry = retry
-        self.response_iterator = read_method(request)
+
+        # The `timeout` parameter must be somewhat greater than the value
+        # contained in `self.retry`, in order to avoid race-like condition and
+        # allow registering the first deadline error before invoking the retry.
+        # Otherwise there is a risk of entering an infinite loop that resets
+        # the timeout counter just before it being triggered. The increment
+        # by 1 second here is customary but should not be much less than that.
+        self.response_iterator = read_method(request, timeout=self.retry._deadline + 1)
 
         self.rows = {}
         self._state = self.STATE_NEW_ROW
@@ -456,7 +470,7 @@ class PartialRowsData(object):
 
     def _read_next(self):
         """Helper for :meth:`__iter__`."""
-        return six.next(self.response_iterator)
+        return next(self.response_iterator)
 
     def _read_next_response(self):
         """Helper for :meth:`__iter__`."""
@@ -476,6 +490,9 @@ class PartialRowsData(object):
                 if self.state != self.NEW_ROW:
                     raise ValueError("The row remains partial / is not committed.")
                 break
+            except InvalidRetryRequest:
+                self._cancelled = True
+                break
 
             for chunk in response.chunks:
                 if self._cancelled:
@@ -526,11 +543,11 @@ class PartialRowsData(object):
     def _update_cell(self, chunk):
         if self._cell is None:
             qualifier = None
-            if chunk.HasField("qualifier"):
-                qualifier = chunk.qualifier.value
+            if "qualifier" in chunk:
+                qualifier = chunk.qualifier
             family = None
-            if chunk.HasField("family_name"):
-                family = chunk.family_name.value
+            if "family_name" in chunk:
+                family = chunk.family_name
 
             self._cell = PartialCellData(
                 chunk.row_key,
@@ -560,8 +577,8 @@ class PartialRowsData(object):
 
         # No reset with other keys
         _raise_if(chunk.row_key)
-        _raise_if(chunk.HasField("family_name"))
-        _raise_if(chunk.HasField("qualifier"))
+        _raise_if("family_name" in chunk)
+        _raise_if("qualifier" in chunk)
         _raise_if(chunk.timestamp_micros)
         _raise_if(chunk.labels)
         _raise_if(chunk.value_size)
@@ -591,7 +608,7 @@ class PartialRowsData(object):
 
 
 class _ReadRowsRequestManager(object):
-    """ Update the ReadRowsRequest message in case of failures by
+    """Update the ReadRowsRequest message in case of failures by
         filtering the already read keys.
 
     :type message: class:`data_messages_v2_pb2.ReadRowsRequest`
@@ -613,34 +630,40 @@ class _ReadRowsRequestManager(object):
         self.rows_read_so_far = rows_read_so_far
 
     def build_updated_request(self):
-        """ Updates the given message request as per last scanned key
-        """
-        r_kwargs = {
-            "table_name": self.message.table_name,
-            "filter": self.message.filter,
-        }
+        """Updates the given message request as per last scanned key"""
+
+        resume_request = data_messages_v2_pb2.ReadRowsRequest()
+        data_messages_v2_pb2.ReadRowsRequest.copy_from(resume_request, self.message)
 
         if self.message.rows_limit != 0:
-            r_kwargs["rows_limit"] = max(
-                1, self.message.rows_limit - self.rows_read_so_far
-            )
+            row_limit_remaining = self.message.rows_limit - self.rows_read_so_far
+            if row_limit_remaining > 0:
+                resume_request.rows_limit = row_limit_remaining
+            else:
+                raise InvalidRetryRequest
 
         # if neither RowSet.row_keys nor RowSet.row_ranges currently exist,
         # add row_range that starts with last_scanned_key as start_key_open
         # to request only rows that have not been returned yet
-        if not self.message.HasField("rows"):
+        if "rows" not in self.message:
             row_range = data_v2_pb2.RowRange(start_key_open=self.last_scanned_key)
-            r_kwargs["rows"] = data_v2_pb2.RowSet(row_ranges=[row_range])
+            resume_request.rows = data_v2_pb2.RowSet(row_ranges=[row_range])
         else:
             row_keys = self._filter_rows_keys()
             row_ranges = self._filter_row_ranges()
-            r_kwargs["rows"] = data_v2_pb2.RowSet(
+
+            if len(row_keys) == 0 and len(row_ranges) == 0:
+                # Avoid sending empty row_keys and row_ranges
+                # if that was not the intention
+                raise InvalidRetryRequest
+
+            resume_request.rows = data_v2_pb2.RowSet(
                 row_keys=row_keys, row_ranges=row_ranges
             )
-        return data_messages_v2_pb2.ReadRowsRequest(**r_kwargs)
+        return resume_request
 
     def _filter_rows_keys(self):
-        """ Helper for :meth:`build_updated_request`"""
+        """Helper for :meth:`build_updated_request`"""
         return [
             row_key
             for row_key in self.message.rows.row_keys
@@ -648,7 +671,7 @@ class _ReadRowsRequestManager(object):
         ]
 
     def _filter_row_ranges(self):
-        """ Helper for :meth:`build_updated_request`"""
+        """Helper for :meth:`build_updated_request`"""
         new_row_ranges = []
 
         for row_range in self.message.rows.row_ranges:
@@ -679,17 +702,17 @@ class _ReadRowsRequestManager(object):
         return new_row_ranges
 
     def _key_already_read(self, key):
-        """ Helper for :meth:`_filter_row_ranges`"""
+        """Helper for :meth:`_filter_row_ranges`"""
         return key <= self.last_scanned_key
 
     @staticmethod
     def _start_key_set(row_range):
-        """ Helper for :meth:`_filter_row_ranges`"""
+        """Helper for :meth:`_filter_row_ranges`"""
         return row_range.start_key_open or row_range.start_key_closed
 
     @staticmethod
     def _end_key_set(row_range):
-        """ Helper for :meth:`_filter_row_ranges`"""
+        """Helper for :meth:`_filter_row_ranges`"""
         return row_range.end_key_open or row_range.end_key_closed
 
 
