@@ -14,20 +14,25 @@
 
 """User-friendly container for Google Cloud Bigtable Table."""
 
-
-from grpc import StatusCode
+from typing import Set
+import warnings
 
 from google.api_core import timeout
-from google.api_core.exceptions import RetryError
+from google.api_core.exceptions import Aborted
+from google.api_core.exceptions import DeadlineExceeded
 from google.api_core.exceptions import NotFound
+from google.api_core.exceptions import RetryError
+from google.api_core.exceptions import ServiceUnavailable
+from google.api_core.gapic_v1.method import DEFAULT
 from google.api_core.retry import if_exception_type
 from google.api_core.retry import Retry
-from google.api_core.gapic_v1.method import wrap_method
-from google.cloud._helpers import _to_bytes
+from google.cloud._helpers import _to_bytes  # type: ignore
+from google.cloud.bigtable.backup import Backup
 from google.cloud.bigtable.column_family import _gc_rule_from_pb
 from google.cloud.bigtable.column_family import ColumnFamily
 from google.cloud.bigtable.batcher import MutationsBatcher
 from google.cloud.bigtable.batcher import FLUSH_COUNT, MAX_ROW_BYTES
+from google.cloud.bigtable.encryption_info import EncryptionInfo
 from google.cloud.bigtable.policy import Policy
 from google.cloud.bigtable.row import AppendRow
 from google.cloud.bigtable.row import ConditionalRow
@@ -37,21 +42,28 @@ from google.cloud.bigtable.row_data import DEFAULT_RETRY_READ_ROWS
 from google.cloud.bigtable.row_set import RowSet
 from google.cloud.bigtable.row_set import RowRange
 from google.cloud.bigtable import enums
-from google.cloud.bigtable_v2.proto import bigtable_pb2 as data_messages_v2_pb2
-from google.cloud.bigtable_admin_v2.proto import table_pb2 as admin_messages_v2_pb2
-from google.cloud.bigtable_admin_v2.proto import (
-    bigtable_table_admin_pb2 as table_admin_messages_v2_pb2,
+from google.cloud.bigtable_v2.types import bigtable as data_messages_v2_pb2
+from google.cloud.bigtable_admin_v2 import BigtableTableAdminClient
+from google.cloud.bigtable_admin_v2.types import table as admin_messages_v2_pb2
+from google.cloud.bigtable_admin_v2.types import (
+    bigtable_table_admin as table_admin_messages_v2_pb2,
 )
 
-import warnings
-
-
 # Maximum number of mutations in bulk (MutateRowsRequest message):
 # (https://cloud.google.com/bigtable/docs/reference/data/rpc/
 #  google.bigtable.v2#google.bigtable.v2.MutateRowRequest)
 _MAX_BULK_MUTATIONS = 100000
 VIEW_NAME_ONLY = enums.Table.View.NAME_ONLY
 
+RETRYABLE_MUTATION_ERRORS = (Aborted, DeadlineExceeded, ServiceUnavailable)
+"""Errors which can be retried during row mutation."""
+
+RETRYABLE_CODES: Set[int] = set()
+
+for retryable in RETRYABLE_MUTATION_ERRORS:
+    if retryable.grpc_status_code is not None:  # pragma: NO COVER
+        RETRYABLE_CODES.add(retryable.grpc_status_code.value[0])
+
 
 class _BigtableRetryableError(Exception):
     """Retry-able error expected by the default retry strategy."""
@@ -117,8 +129,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_table_name]
-            :end-before: [END bigtable_table_name]
+            :start-after: [START bigtable_api_table_name]
+            :end-before: [END bigtable_api_table_name]
+            :dedent: 4
 
         .. note::
 
@@ -145,14 +158,15 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_table_get_iam_policy]
-            :end-before: [END bigtable_table_get_iam_policy]
+            :start-after: [START bigtable_api_table_get_iam_policy]
+            :end-before: [END bigtable_api_table_get_iam_policy]
+            :dedent: 4
 
         :rtype: :class:`google.cloud.bigtable.policy.Policy`
         :returns: The current IAM policy of this table.
         """
         table_client = self._instance._client.table_admin_client
-        resp = table_client.get_iam_policy(resource=self.name)
+        resp = table_client.get_iam_policy(request={"resource": self.name})
         return Policy.from_pb(resp)
 
     def set_iam_policy(self, policy):
@@ -165,8 +179,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_table_set_iam_policy]
-            :end-before: [END bigtable_table_set_iam_policy]
+            :start-after: [START bigtable_api_table_set_iam_policy]
+            :end-before: [END bigtable_api_table_set_iam_policy]
+            :dedent: 4
 
         :type policy: :class:`google.cloud.bigtable.policy.Policy`
         :param policy: A new IAM policy to replace the current IAM policy
@@ -176,7 +191,9 @@ class Table(object):
         :returns: The current IAM policy of this table.
         """
         table_client = self._instance._client.table_admin_client
-        resp = table_client.set_iam_policy(resource=self.name, policy=policy.to_pb())
+        resp = table_client.set_iam_policy(
+            request={"resource": self.name, "policy": policy.to_pb()}
+        )
         return Policy.from_pb(resp)
 
     def test_iam_permissions(self, permissions):
@@ -186,8 +203,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_table_test_iam_permissions]
-            :end-before: [END bigtable_table_test_iam_permissions]
+            :start-after: [START bigtable_api_table_test_iam_permissions]
+            :end-before: [END bigtable_api_table_test_iam_permissions]
+            :dedent: 4
 
         :type permissions: list
         :param permissions: The set of permissions to check for
@@ -203,7 +221,7 @@ class Table(object):
         """
         table_client = self._instance._client.table_admin_client
         resp = table_client.test_iam_permissions(
-            resource=self.name, permissions=permissions
+            request={"resource": self.name, "permissions": permissions}
         )
         return list(resp.permissions)
 
@@ -213,8 +231,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_table_column_family]
-            :end-before: [END bigtable_table_column_family]
+            :start-after: [START bigtable_api_table_column_family]
+            :end-before: [END bigtable_api_table_column_family]
+            :dedent: 4
 
         :type column_family_id: str
         :param column_family_id: The ID of the column family. Must be of the
@@ -235,8 +254,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_table_row]
-            :end-before: [END bigtable_table_row]
+            :start-after: [START bigtable_api_table_row]
+            :end-before: [END bigtable_api_table_row]
+            :dedent: 4
 
         .. warning::
 
@@ -282,8 +302,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_table_append_row]
-            :end-before: [END bigtable_table_append_row]
+            :start-after: [START bigtable_api_table_append_row]
+            :end-before: [END bigtable_api_table_append_row]
+            :dedent: 4
 
         Args:
             row_key (bytes): The key for the row being created.
@@ -299,8 +320,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_table_direct_row]
-            :end-before: [END bigtable_table_direct_row]
+            :start-after: [START bigtable_api_table_direct_row]
+            :end-before: [END bigtable_api_table_direct_row]
+            :dedent: 4
 
         Args:
             row_key (bytes): The key for the row being created.
@@ -316,8 +338,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_table_conditional_row]
-            :end-before: [END bigtable_table_conditional_row]
+            :start-after: [START bigtable_api_table_conditional_row]
+            :end-before: [END bigtable_api_table_conditional_row]
+            :dedent: 4
 
         Args:
             row_key (bytes): The key for the row being created.
@@ -344,13 +367,14 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_create_table]
-            :end-before: [END bigtable_create_table]
+            :start-after: [START bigtable_api_create_table]
+            :end-before: [END bigtable_api_create_table]
+            :dedent: 4
 
         .. note::
 
             A create request returns a
-            :class:`._generated.table_pb2.Table` but we don't use
+            :class:`._generated.table.Table` but we don't use
             this response.
 
         :type initial_split_keys: list
@@ -376,10 +400,12 @@ class Table(object):
         splits = [split(key=_to_bytes(key)) for key in initial_split_keys]
 
         table_client.create_table(
-            parent=instance_name,
-            table_id=self.table_id,
-            table=table,
-            initial_splits=splits,
+            request={
+                "parent": instance_name,
+                "table_id": self.table_id,
+                "table": table,
+                "initial_splits": splits,
+            }
         )
 
     def exists(self):
@@ -388,15 +414,16 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_check_table_exists]
-            :end-before: [END bigtable_check_table_exists]
+            :start-after: [START bigtable_api_check_table_exists]
+            :end-before: [END bigtable_api_check_table_exists]
+            :dedent: 4
 
         :rtype: bool
         :returns: True if the table exists, else False.
         """
         table_client = self._instance._client.table_admin_client
         try:
-            table_client.get_table(name=self.name, view=VIEW_NAME_ONLY)
+            table_client.get_table(request={"name": self.name, "view": VIEW_NAME_ONLY})
             return True
         except NotFound:
             return False
@@ -407,12 +434,12 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_delete_table]
-            :end-before: [END bigtable_delete_table]
-
+            :start-after: [START bigtable_api_delete_table]
+            :end-before: [END bigtable_api_delete_table]
+            :dedent: 4
         """
         table_client = self._instance._client.table_admin_client
-        table_client.delete_table(name=self.name)
+        table_client.delete_table(request={"name": self.name})
 
     def list_column_families(self):
         """List the column families owned by this table.
@@ -420,8 +447,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_list_column_families]
-            :end-before: [END bigtable_list_column_families]
+            :start-after: [START bigtable_api_list_column_families]
+            :end-before: [END bigtable_api_list_column_families]
+            :dedent: 4
 
         :rtype: dict
         :returns: Dictionary of column families attached to this table. Keys
@@ -432,7 +460,7 @@ class Table(object):
                  name from the column family ID.
         """
         table_client = self._instance._client.table_admin_client
-        table_pb = table_client.get_table(self.name)
+        table_pb = table_client.get_table(request={"name": self.name})
 
         result = {}
         for column_family_id, value_pb in table_pb.column_families.items():
@@ -447,8 +475,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_get_cluster_states]
-            :end-before: [END bigtable_get_cluster_states]
+            :start-after: [START bigtable_api_get_cluster_states]
+            :end-before: [END bigtable_api_get_cluster_states]
+            :dedent: 4
 
         :rtype: dict
         :returns: Dictionary of cluster states for this table.
@@ -458,21 +487,51 @@ class Table(object):
 
         REPLICATION_VIEW = enums.Table.View.REPLICATION_VIEW
         table_client = self._instance._client.table_admin_client
-        table_pb = table_client.get_table(self.name, view=REPLICATION_VIEW)
+        table_pb = table_client.get_table(
+            request={"name": self.name, "view": REPLICATION_VIEW}
+        )
 
         return {
             cluster_id: ClusterState(value_pb.replication_state)
             for cluster_id, value_pb in table_pb.cluster_states.items()
         }
 
+    def get_encryption_info(self):
+        """List the encryption info for each cluster owned by this table.
+
+        Gets the current encryption info for the table across all of the clusters.  The
+        returned dict will be keyed by cluster id and contain a status for all of the
+        keys in use.
+
+        :rtype: dict
+        :returns: Dictionary of encryption info for this table. Keys are cluster ids and
+                  values are tuples of :class:`google.cloud.bigtable.encryption.EncryptionInfo` instances.
+        """
+        ENCRYPTION_VIEW = enums.Table.View.ENCRYPTION_VIEW
+        table_client = self._instance._client.table_admin_client
+        table_pb = table_client.get_table(
+            request={"name": self.name, "view": ENCRYPTION_VIEW}
+        )
+
+        return {
+            cluster_id: tuple(
+                (
+                    EncryptionInfo._from_pb(info_pb)
+                    for info_pb in value_pb.encryption_info
+                )
+            )
+            for cluster_id, value_pb in table_pb.cluster_states.items()
+        }
+
     def read_row(self, row_key, filter_=None):
         """Read a single row from this table.
 
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_read_row]
-            :end-before: [END bigtable_read_row]
+            :start-after: [START bigtable_api_read_row]
+            :end-before: [END bigtable_api_read_row]
+            :dedent: 4
 
         :type row_key: bytes
         :param row_key: The key of the row to read from.
@@ -510,8 +569,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_read_rows]
-            :end-before: [END bigtable_read_rows]
+            :start-after: [START bigtable_api_read_rows]
+            :end-before: [END bigtable_api_read_rows]
+            :dedent: 4
 
         :type start_key: bytes
         :param start_key: (Optional) The beginning of a range of row keys to
@@ -537,7 +597,7 @@ class Table(object):
         :param end_inclusive: (Optional) Whether the ``end_key`` should be
                       considered inclusive. The default is False (exclusive).
 
-        :type row_set: :class:`row_set.RowSet`
+        :type row_set: :class:`.RowSet`
         :param row_set: (Optional) The row set containing multiple row keys and
                         row_ranges.
 
@@ -564,7 +624,7 @@ class Table(object):
             row_set=row_set,
         )
         data_client = self._instance._client.table_data_client
-        return PartialRowsData(data_client.transport.read_rows, request_pb, retry)
+        return PartialRowsData(data_client.read_rows, request_pb, retry)
 
     def yield_rows(self, **kwargs):
         """Read rows from this table.
@@ -593,7 +653,7 @@ class Table(object):
                         specified row(s). If unset, reads every column in
                         each row.
 
-        :type row_set: :class:`row_set.RowSet`
+        :type row_set: :class:`.RowSet`
         :param row_set: (Optional) The row set containing multiple row keys and
                         row_ranges.
 
@@ -607,14 +667,15 @@ class Table(object):
         )
         return self.read_rows(**kwargs)
 
-    def mutate_rows(self, rows, retry=DEFAULT_RETRY):
+    def mutate_rows(self, rows, retry=DEFAULT_RETRY, timeout=DEFAULT):
         """Mutates multiple rows in bulk.
 
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_mutate_rows]
-            :end-before: [END bigtable_mutate_rows]
+            :start-after: [START bigtable_api_mutate_rows]
+            :end-before: [END bigtable_api_mutate_rows]
+            :dedent: 4
 
         The method tries to update all specified rows.
         If some of the rows weren't updated, it would not remove mutations.
@@ -637,17 +698,23 @@ class Table(object):
             the :meth:`~google.api_core.retry.Retry.with_delay` method or the
             :meth:`~google.api_core.retry.Retry.with_deadline` method.
 
+        :type timeout: float
+        :param timeout: number of seconds bounding retries for the call
+
         :rtype: list
         :returns: A list of response statuses (`google.rpc.status_pb2.Status`)
                   corresponding to success or failure of each row mutation
                   sent. These will be in the same order as the `rows`.
         """
+        if timeout is DEFAULT:
+            timeout = self.mutation_timeout
+
         retryable_mutate_rows = _RetryableMutateRowsWorker(
             self._instance._client,
             self.name,
             rows,
             app_profile_id=self._app_profile_id,
-            timeout=self.mutation_timeout,
+            timeout=timeout,
         )
         return retryable_mutate_rows(retry=retry)
 
@@ -657,8 +724,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_sample_row_keys]
-            :end-before: [END bigtable_sample_row_keys]
+            :start-after: [START bigtable_api_sample_row_keys]
+            :end-before: [END bigtable_api_sample_row_keys]
+            :dedent: 4
 
         The returned row keys will delimit contiguous sections of the table of
         approximately equal size, which can be used to break up the data for
@@ -690,7 +758,7 @@ class Table(object):
         """
         data_client = self._instance._client.table_data_client
         response_iterator = data_client.sample_row_keys(
-            self.name, app_profile_id=self._app_profile_id
+            request={"table_name": self.name, "app_profile_id": self._app_profile_id}
         )
 
         return response_iterator
@@ -701,8 +769,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_truncate_table]
-            :end-before: [END bigtable_truncate_table]
+            :start-after: [START bigtable_api_truncate_table]
+            :end-before: [END bigtable_api_truncate_table]
+            :dedent: 4
 
         :type timeout: float
         :param timeout: (Optional) The amount of time, in seconds, to wait
@@ -718,11 +787,12 @@ class Table(object):
         table_admin_client = client.table_admin_client
         if timeout:
             table_admin_client.drop_row_range(
-                self.name, delete_all_data_from_table=True, timeout=timeout
+                request={"name": self.name, "delete_all_data_from_table": True},
+                timeout=timeout,
             )
         else:
             table_admin_client.drop_row_range(
-                self.name, delete_all_data_from_table=True
+                request={"name": self.name, "delete_all_data_from_table": True}
             )
 
     def drop_by_prefix(self, row_key_prefix, timeout=None):
@@ -731,8 +801,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_drop_by_prefix]
-            :end-before: [END bigtable_drop_by_prefix]
+            :start-after: [START bigtable_api_drop_by_prefix]
+            :end-before: [END bigtable_api_drop_by_prefix]
+            :dedent: 4
 
         :type row_key_prefix: bytes
         :param row_key_prefix: Delete all rows that start with this row key
@@ -752,11 +823,15 @@ class Table(object):
         table_admin_client = client.table_admin_client
         if timeout:
             table_admin_client.drop_row_range(
-                self.name, row_key_prefix=_to_bytes(row_key_prefix), timeout=timeout
+                request={
+                    "name": self.name,
+                    "row_key_prefix": _to_bytes(row_key_prefix),
+                },
+                timeout=timeout,
             )
         else:
             table_admin_client.drop_row_range(
-                self.name, row_key_prefix=_to_bytes(row_key_prefix)
+                request={"name": self.name, "row_key_prefix": _to_bytes(row_key_prefix)}
             )
 
     def mutations_batcher(self, flush_count=FLUSH_COUNT, max_row_bytes=MAX_ROW_BYTES):
@@ -765,8 +840,9 @@ class Table(object):
         For example:
 
         .. literalinclude:: snippets_table.py
-            :start-after: [START bigtable_mutations_batcher]
-            :end-before: [END bigtable_mutations_batcher]
+            :start-after: [START bigtable_api_mutations_batcher]
+            :end-before: [END bigtable_api_mutations_batcher]
+            :dedent: 4
 
         :type flush_count: int
         :param flush_count: (Optional) Maximum number of rows per batch. If it
@@ -782,6 +858,189 @@ class Table(object):
         """
         return MutationsBatcher(self, flush_count, max_row_bytes)
 
+    def backup(self, backup_id, cluster_id=None, expire_time=None):
+        """Factory to create a Backup linked to this Table.
+
+        :type backup_id: str
+        :param backup_id: The ID of the Backup to be created.
+
+        :type cluster_id: str
+        :param cluster_id: (Optional) The ID of the Cluster. Required for
+                           calling 'delete', 'exists' etc. methods.
+
+        :type expire_time: :class:`datetime.datetime`
+        :param expire_time: (Optional) The expiration time of this new Backup.
+            Required, if the `create` method needs to be called.
+        :rtype: :class:`.Backup`
+        :returns: A backup linked to this table.
+        """
+        return Backup(
+            backup_id,
+            self._instance,
+            cluster_id=cluster_id,
+            table_id=self.table_id,
+            expire_time=expire_time,
+        )
+
+    def list_backups(self, cluster_id=None, filter_=None, order_by=None, page_size=0):
+        """List Backups for this Table.
+
+        :type cluster_id: str
+        :param cluster_id: (Optional) Specifies a single cluster to list
+                           Backups from. If none is specified, the returned list
+                           contains all the Backups in this Instance.
+
+        :type filter_: str
+        :param filter_: (Optional) A filter expression that filters backups
+                        listed in the response. The expression must specify
+                        the field name, a comparison operator, and the value
+                        that you want to use for filtering. The value must be
+                        a string, a number, or a boolean. The comparison
+                        operator must be <, >, <=, >=, !=, =, or :. Colon ':'
+                        represents a HAS operator which is roughly synonymous
+                        with equality. Filter rules are case insensitive.
+
+                        The fields eligible for filtering are:
+
+                -  ``name``
+                -  ``source_table``
+                -  ``state``
+                -  ``start_time`` (values of the format YYYY-MM-DDTHH:MM:SSZ)
+                -  ``end_time`` (values of the format YYYY-MM-DDTHH:MM:SSZ)
+                -  ``expire_time`` (values of the format YYYY-MM-DDTHH:MM:SSZ)
+                -  ``size_bytes``
+
+                        To filter on multiple expressions, provide each
+                        separate expression within parentheses. By default,
+                        each expression is an AND expression. However, you can
+                        include AND, OR, and NOT expressions explicitly.
+
+                        Some examples of using filters are:
+
+                -  ``name:"exact"`` --> The Backup name is the string "exact".
+                -  ``name:howl`` --> The Backup name contains the string "howl"
+                -  ``source_table:prod`` --> The source table's name contains
+                        the string "prod".
+                -  ``state:CREATING`` --> The Backup is pending creation.
+                -  ``state:READY`` --> The Backup is created and ready for use.
+                -  ``(name:howl) AND (start_time < \"2020-05-28T14:50:00Z\")``
+                        --> The Backup name contains the string "howl" and
+                        the Backup start time is before 2020-05-28T14:50:00Z.
+                -  ``size_bytes > 10000000000`` --> The Backup size is greater
+                        than 10GB
+
+        :type order_by: str
+        :param order_by: (Optional) An expression for specifying the sort order
+                         of the results of the request. The string value should
+                         specify one or more fields in ``Backup``. The full
+                         syntax is described at https://aip.dev/132#ordering.
+
+                         Fields supported are: \\* name \\* source_table \\*
+                         expire_time \\* start_time \\* end_time \\*
+                         size_bytes \\* state
+
+                         For example, "start_time". The default sorting order
+                         is ascending. To specify descending order for the
+                         field, a suffix " desc" should be appended to the
+                         field name. For example, "start_time desc". Redundant
+                         space characters in the syntax are insigificant. If
+                         order_by is empty, results will be sorted by
+                         ``start_time`` in descending order starting from
+                         the most recently created backup.
+
+        :type page_size: int
+        :param page_size: (Optional) The maximum number of resources contained
+                          in the underlying API response. If page streaming is
+                          performed per-resource, this parameter does not
+                          affect the return value. If page streaming is
+                          performed per-page, this determines the maximum
+                          number of resources in a page.
+
+        :rtype: :class:`~google.api_core.page_iterator.Iterator`
+        :returns: Iterator of :class:`~google.cloud.bigtable.backup.Backup`
+                  resources within the current Instance.
+        :raises: :class:`ValueError <exceptions.ValueError>` if one of the
+                 returned Backups' name is not of the expected format.
+        """
+        cluster_id = cluster_id or "-"
+
+        backups_filter = "source_table:{}".format(self.name)
+        if filter_:
+            backups_filter = "({}) AND ({})".format(backups_filter, filter_)
+
+        parent = BigtableTableAdminClient.cluster_path(
+            project=self._instance._client.project,
+            instance=self._instance.instance_id,
+            cluster=cluster_id,
+        )
+        client = self._instance._client.table_admin_client
+        backup_list_pb = client.list_backups(
+            request={
+                "parent": parent,
+                "filter": backups_filter,
+                "order_by": order_by,
+                "page_size": page_size,
+            }
+        )
+
+        result = []
+        for backup_pb in backup_list_pb.backups:
+            result.append(Backup.from_pb(backup_pb, self._instance))
+
+        return result
+
+    def restore(self, new_table_id, cluster_id=None, backup_id=None, backup_name=None):
+        """Creates a new Table by restoring from the Backup specified by either
+        `backup_id` or `backup_name`. The returned ``long-running operation``
+        can be used to track the progress of the operation and to cancel it.
+        The ``response`` type is ``Table``, if successful.
+
+        :type new_table_id: str
+        :param new_table_id: The ID of the Table to create and restore to.
+                         This Table must not already exist.
+
+        :type cluster_id: str
+        :param cluster_id: The ID of the Cluster containing the Backup.
+                           This parameter gets overriden by `backup_name`, if
+                           the latter is provided.
+
+        :type backup_id: str
+        :param backup_id: The ID of the Backup to restore the Table from.
+                          This parameter gets overriden by `backup_name`, if
+                          the latter is provided.
+
+        :type backup_name: str
+        :param backup_name: (Optional) The full name of the Backup to restore
+                            from. If specified, it overrides the `cluster_id`
+                            and `backup_id` parameters even of such specified.
+
+        :return: An instance of
+             :class:`~google.cloud.bigtable_admin_v2.types._OperationFuture`.
+
+        :raises: google.api_core.exceptions.AlreadyExists: If the table
+                 already exists.
+        :raises: google.api_core.exceptions.GoogleAPICallError: If the request
+                 failed for any reason.
+        :raises: google.api_core.exceptions.RetryError: If the request failed
+                 due to a retryable error and retry attempts failed.
+        :raises: ValueError: If the parameters are invalid.
+        """
+        api = self._instance._client.table_admin_client
+        if not backup_name:
+            backup_name = BigtableTableAdminClient.backup_path(
+                project=self._instance._client.project,
+                instance=self._instance.instance_id,
+                cluster=cluster_id,
+                backup=backup_id,
+            )
+        return api.restore_table(
+            request={
+                "parent": self._instance.name,
+                "table_id": new_table_id,
+                "backup": backup_name,
+            }
+        )
+
 
 class _RetryableMutateRowsWorker(object):
     """A callable worker that can retry to mutate rows with transient errors.
@@ -791,14 +1050,6 @@ class _RetryableMutateRowsWorker(object):
     are retryable, any subsequent call on this callable will be a no-op.
     """
 
-    # pylint: disable=unsubscriptable-object
-    RETRY_CODES = (
-        StatusCode.DEADLINE_EXCEEDED.value[0],
-        StatusCode.ABORTED.value[0],
-        StatusCode.UNAVAILABLE.value[0],
-    )
-    # pylint: enable=unsubscriptable-object
-
     def __init__(self, client, table_name, rows, app_profile_id=None, timeout=None):
         self.client = client
         self.table_name = table_name
@@ -835,7 +1086,7 @@ class _RetryableMutateRowsWorker(object):
 
     @staticmethod
     def _is_retryable(status):
-        return status is None or status.code in _RetryableMutateRowsWorker.RETRY_CODES
+        return status is None or status.code in RETRYABLE_CODES
 
     def _do_mutate_retryable_rows(self):
         """Mutate all the rows that are eligible for retry.
@@ -864,27 +1115,26 @@ class _RetryableMutateRowsWorker(object):
             # All mutations are either successful or non-retryable now.
             return self.responses_statuses
 
-        mutate_rows_request = _mutate_rows_request(
-            self.table_name, retryable_rows, app_profile_id=self.app_profile_id
-        )
+        entries = _compile_mutation_entries(self.table_name, retryable_rows)
         data_client = self.client.table_data_client
-        inner_api_calls = data_client._inner_api_calls
-        if "mutate_rows" not in inner_api_calls:
-            default_retry = (data_client._method_configs["MutateRows"].retry,)
-            if self.timeout is None:
-                default_timeout = data_client._method_configs["MutateRows"].timeout
-            else:
-                default_timeout = timeout.ExponentialTimeout(deadline=self.timeout)
-            data_client._inner_api_calls["mutate_rows"] = wrap_method(
-                data_client.transport.mutate_rows,
-                default_retry=default_retry,
-                default_timeout=default_timeout,
-                client_info=data_client._client_info,
-            )
 
-        responses = data_client._inner_api_calls["mutate_rows"](
-            mutate_rows_request, retry=None
-        )
+        kwargs = {}
+        if self.timeout is not None:
+            kwargs["timeout"] = timeout.ExponentialTimeout(deadline=self.timeout)
+
+        try:
+            responses = data_client.mutate_rows(
+                table_name=self.table_name,
+                entries=entries,
+                app_profile_id=self.app_profile_id,
+                retry=None,
+                **kwargs
+            )
+        except RETRYABLE_MUTATION_ERRORS:
+            # If an exception, considered retryable by `RETRYABLE_MUTATION_ERRORS`, is
+            # returned from the initial call, consider
+            # it to be retryable. Wrap as a Bigtable Retryable Error.
+            raise _BigtableRetryableError
 
         num_responses = 0
         num_retryable_responses = 0
@@ -1028,7 +1278,7 @@ def _create_row_request(
     :type: app_profile_id: str
     :param app_profile_id: (Optional) The unique name of the AppProfile.
 
-    :type row_set: :class:`row_set.RowSet`
+    :type row_set: :class:`.RowSet`
     :param row_set: (Optional) The row set containing multiple row keys and
                     row_ranges.
 
@@ -1060,8 +1310,8 @@ def _create_row_request(
     return message
 
 
-def _mutate_rows_request(table_name, rows, app_profile_id=None):
-    """Creates a request to mutate rows in a table.
+def _compile_mutation_entries(table_name, rows):
+    """Create list of mutation entries
 
     :type table_name: str
     :param table_name: The name of the table to write to.
@@ -1069,29 +1319,29 @@ def _mutate_rows_request(table_name, rows, app_profile_id=None):
     :type rows: list
     :param rows: List or other iterable of :class:`.DirectRow` instances.
 
-    :type: app_profile_id: str
-    :param app_profile_id: (Optional) The unique name of the AppProfile.
-
-    :rtype: :class:`data_messages_v2_pb2.MutateRowsRequest`
-    :returns: The ``MutateRowsRequest`` protobuf corresponding to the inputs.
+    :rtype: List[:class:`data_messages_v2_pb2.MutateRowsRequest.Entry`]
+    :returns: entries corresponding to the inputs.
     :raises: :exc:`~.table.TooManyMutationsError` if the number of mutations is
-             greater than 100,000
-    """
-    request_pb = data_messages_v2_pb2.MutateRowsRequest(
-        table_name=table_name, app_profile_id=app_profile_id
+             greater than the max ({})
+    """.format(
+        _MAX_BULK_MUTATIONS
     )
+    entries = []
     mutations_count = 0
+    entry_klass = data_messages_v2_pb2.MutateRowsRequest.Entry
+
     for row in rows:
         _check_row_table_name(table_name, row)
         _check_row_type(row)
         mutations = row._get_mutations()
-        request_pb.entries.add(row_key=row.row_key, mutations=mutations)
+        entries.append(entry_klass(row_key=row.row_key, mutations=mutations))
         mutations_count += len(mutations)
+
     if mutations_count > _MAX_BULK_MUTATIONS:
         raise TooManyMutationsError(
             "Maximum number of mutations is %s" % (_MAX_BULK_MUTATIONS,)
         )
-    return request_pb
+    return entries
 
 
 def _check_row_table_name(table_name, row):
